import akka.util.ByteString
import org.scalacheck.Arbitrary._
import org.scalacheck.{Arbitrary, Gen}
import org.scalacheck.Gen._
import org.scalatest.prop.Checkers
import org.scalatest.{ Matchers, WordSpec }

class Broken extends WordSpec with Matchers with Checkers {

  def genSimpleByteString(min: Int, max: Int) = for {
    n ← choose(min, max)
    b ← Gen.containerOfN[Array, Byte](n, arbitrary[Byte])
    from ← choose(0, b.length)
    until ← choose(from, b.length)
  } yield ByteString(b).slice(from, until)

  implicit val arbitraryByteString: Arbitrary[ByteString] = Arbitrary {
    Gen.sized { s ⇒
      for {
        chunks ← choose(0, s)
        bytes ← listOfN(chunks, genSimpleByteString(1, s / (chunks max 1)))
      } yield (ByteString.empty /: bytes)(_ ++ _)
    }
  }

  "Some thing" must {
    "when calling copyToBuffer" in {
      check { bytes: ByteString ⇒
        import java.nio.ByteBuffer
        val buffer = ByteBuffer.allocate(bytes.size)
        bytes.copyToBuffer(buffer)
        buffer.flip()
        val array = Array.ofDim[Byte](bytes.size)
        buffer.get(array)
        // This fails to compile without giving file/line information
        bytes == array.toSeq
      }
    }
  }
}
